@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2015, 2016 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,12 +21,13 @@
 #include <errno.h>
 #include <string.h>
 
+#include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <gio/gdesktopappinfo.h>
 #include <rest/rest-proxy.h>
 #include <libsoup/soup.h>
 
 #include "goadaemon.h"
+#include "goa/goa.h"
 #include "goabackend/goabackend.h"
 #include "goabackend/goaprovider-priv.h"
 #include "goabackend/goautils.h"
@@ -54,11 +55,6 @@ struct _GoaDaemon
   guint credentials_timeout_id;
 };
 
-typedef struct
-{
-  GObjectClass parent_class;
-} GoaDaemonClass;
-
 static void on_file_monitor_changed (GFileMonitor     *monitor,
                                      GFile            *file,
                                      GFile            *other_file,
