@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013, 2014, 2015, 2016 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -361,7 +361,7 @@ ensure_credentials_sync (GoaProvider         *provider,
                            * username (eg., rishi), and the (%s, %d)
                            * is the error domain and code.
                            */
-                          _("Invalid %s with username ‘%s’ (%s, %d): "),
+                          _("Invalid %s with username “%s” (%s, %d): "),
                           "imap-password",
                           imap_username,
                           g_quark_to_string ((*error)->domain),
@@ -412,7 +412,7 @@ ensure_credentials_sync (GoaProvider         *provider,
                            * username (eg., rishi), and the (%s, %d)
                            * is the error domain and code.
                            */
-                          _("Invalid %s with username ‘%s’ (%s, %d): "),
+                          _("Invalid %s with username “%s” (%s, %d): "),
                           "smtp-password",
                           smtp_username,
                           g_quark_to_string ((*error)->domain),
@@ -1508,16 +1508,25 @@ show_account (GoaProvider         *provider,
               GoaClient           *client,
               GoaObject           *object,
               GtkBox              *vbox,
-              GtkGrid             *grid,
-              G_GNUC_UNUSED GtkGrid *dummy)
+              G_GNUC_UNUSED GtkGrid *dummy1,
+              G_GNUC_UNUSED GtkGrid *dummy2)
 {
+  GtkWidget *grid;
   const gchar *username;
   gchar *value_str;
   gchar *value_str_1;
   gint row;
 
   row = 0;
-  goa_util_add_account_info (grid, row++, object);
+
+  grid = gtk_grid_new ();
+  gtk_widget_set_halign (grid, GTK_ALIGN_CENTER);
+  gtk_widget_set_hexpand (grid, TRUE);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+  gtk_box_pack_start (vbox, grid, FALSE, TRUE, 0);
+
+  goa_utils_account_add_header (object, GTK_GRID (grid), row++);
 
   username = g_get_user_name ();
 
@@ -1558,6 +1567,8 @@ show_account (GoaProvider         *provider,
       show_label (GTK_WIDGET (grid), row++, _("SMTP"), value_str);
   g_free (value_str_1);
   g_free (value_str);
+
+  goa_utils_account_add_attention_needed (client, object, provider, vbox);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
