@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2013, 2014, 2015, 2016 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -101,9 +101,7 @@ static void goa_provider_show_account_real (GoaProvider         *provider,
                                             GtkGrid             *dummy1,
                                             GtkGrid             *dummy2);
 
-#define GOA_PROVIDER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOA_TYPE_PROVIDER, GoaProviderPrivate))
-
-G_DEFINE_ABSTRACT_TYPE (GoaProvider, goa_provider, G_TYPE_OBJECT);
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GoaProvider, goa_provider, G_TYPE_OBJECT);
 
 static struct {
   GoaProviderFeatures feature;
@@ -188,10 +186,13 @@ goa_provider_get_property (GObject *object,
                            GParamSpec *pspec)
 {
     GoaProvider *self = GOA_PROVIDER (object);
+    GoaProviderPrivate *priv;
+
+    priv = goa_provider_get_instance_private (self);
 
     switch (property_id) {
     case PROP_PRESEED_DATA:
-        g_value_set_variant (value, self->priv->preseed_data);
+        g_value_set_variant (value, priv->preseed_data);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -221,8 +222,11 @@ static void
 goa_provider_dispose (GObject *object)
 {
   GoaProvider *self = GOA_PROVIDER (object);
+  GoaProviderPrivate *priv;
 
-  g_clear_pointer (&self->priv->preseed_data, g_variant_unref);
+  priv = goa_provider_get_instance_private (self);
+
+  g_clear_pointer (&priv->preseed_data, g_variant_unref);
 
   G_OBJECT_CLASS (goa_provider_parent_class)->dispose (object);
 }
@@ -230,7 +234,6 @@ goa_provider_dispose (GObject *object)
 static void
 goa_provider_init (GoaProvider *self)
 {
-  self->priv = GOA_PROVIDER_GET_PRIVATE (self);
 }
 
 static void
@@ -238,8 +241,6 @@ goa_provider_class_init (GoaProviderClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GoaProviderPrivate));
-
   object_class->set_property = goa_provider_set_property;
   object_class->get_property = goa_provider_get_property;
   object_class->dispose = goa_provider_dispose;
@@ -1401,9 +1402,13 @@ void
 goa_provider_set_preseed_data (GoaProvider *self,
                                GVariant    *preseed_data)
 {
-  g_clear_pointer (&self->priv->preseed_data, g_variant_unref);
+  GoaProviderPrivate *priv;
+
+  priv = goa_provider_get_instance_private (self);
+
+  g_clear_pointer (&priv->preseed_data, g_variant_unref);
   if (preseed_data != NULL)
-    self->priv->preseed_data = g_variant_ref_sink (preseed_data);
+    priv->preseed_data = g_variant_ref_sink (preseed_data);
   g_object_notify (G_OBJECT (self), "preseed-data");
 }
 
@@ -1419,7 +1424,10 @@ goa_provider_set_preseed_data (GoaProvider *self,
 GVariant *
 goa_provider_get_preseed_data (GoaProvider *self)
 {
-  return self->priv->preseed_data;
+  GoaProviderPrivate *priv;
+
+  priv = goa_provider_get_instance_private (self);
+  return priv->preseed_data;
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
