@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013, 2015, 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,6 @@
 #include <telepathy-glib/telepathy-glib.h>
 #endif
 
-#include "goaprovider.h"
 #include "goautils.h"
 
 static const SecretSchema secret_password_schema =
@@ -552,6 +551,108 @@ goa_utils_store_credentials_for_object_sync (GoaProvider   *provider,
   return goa_utils_store_credentials_for_id_sync (provider, id, credentials, cancellable, error);
 }
 
+gboolean
+goa_utils_keyfile_copy_group (GKeyFile     *src_key_file,
+                              const gchar  *src_group_name,
+                              GKeyFile     *dest_key_file,
+                              const gchar  *dest_group_name)
+{
+  GError *error;
+  gboolean ret_val = FALSE;
+  gchar **keys = NULL;
+  gsize i;
+
+  error = NULL;
+  keys = g_key_file_get_keys (src_key_file, src_group_name, NULL, &error);
+  if (error != NULL)
+    {
+      g_warning ("Error getting keys from group %s: %s (%s, %d)",
+                 src_group_name,
+                 error->message,
+                 g_quark_to_string (error->domain),
+                 error->code);
+      g_error_free (error);
+      goto out;
+    }
+
+  for (i = 0; keys[i] != NULL; i++)
+    {
+      gchar *dest_value;
+      gchar *src_value;
+
+      error = NULL;
+      src_value = g_key_file_get_value (src_key_file, src_group_name, keys[i], &error);
+      if (error != NULL)
+        {
+          g_warning ("Error reading key %s from group %s: %s (%s, %d)",
+                     keys[i],
+                     src_group_name,
+                     error->message,
+                     g_quark_to_string (error->domain),
+                     error->code);
+          g_error_free (error);
+          continue;
+        }
+
+      error = NULL;
+      dest_value = g_key_file_get_value (dest_key_file, dest_group_name, keys[i], &error);
+      if (error != NULL)
+        {
+          if (!g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND)
+              && !g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND))
+            {
+              g_warning ("Error reading key %s from group %s: %s (%s, %d)",
+                         keys[i],
+                         src_group_name,
+                         error->message,
+                         g_quark_to_string (error->domain),
+                         error->code);
+            }
+
+          g_error_free (error);
+        }
+
+      if (g_strcmp0 (dest_value, src_value) != 0)
+        {
+          g_key_file_set_value (dest_key_file, dest_group_name, keys[i], src_value);
+          ret_val = TRUE;
+        }
+
+      g_free (dest_value);
+      g_free (src_value);
+    }
+
+ out:
+  g_strfreev (keys);
+  return ret_val;
+}
+
+gboolean
+goa_utils_keyfile_get_boolean (GKeyFile *key_file, const gchar *group_name, const gchar *key)
+{
+  GError *error;
+  gboolean ret;
+
+  error = NULL;
+  ret = g_key_file_get_boolean (key_file, group_name, key, &error);
+  if (error != NULL)
+    {
+      if (!g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND))
+        {
+          g_warning ("Error reading key %s from group %s in keyfile: %s (%s, %d)",
+                     key,
+                     group_name,
+                     error->message,
+                     g_quark_to_string (error->domain),
+                     error->code);
+        }
+
+      g_error_free (error);
+    }
+
+  return ret;
+}
+
 void
 goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
 {
@@ -864,7 +965,7 @@ goa_utils_get_credentials (GoaProvider    *provider,
   if (!g_variant_lookup (credentials, id, "s", &password))
     {
       g_set_error (error, GOA_ERROR, GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Did not find %s with identity ‘%s’ in credentials"),
+                   _("Did not find %s with identity “%s” in credentials"),
                    id, username);
       goto out;
     }
