@@ -1,7 +1,7 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2013, 2014, 2015 Red Hat, Inc.
- * Copyright (C) 2011 Collabora Ltd.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
+ * Copyright © 2011 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,6 @@
 
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
-#include "goaoauth2provider.h"
 #include "goawindowsliveprovider.h"
 #include "goaobjectskeletonutils.h"
 
@@ -41,13 +40,6 @@ struct _GoaWindowsLiveProvider
   GoaOAuth2Provider parent_instance;
 };
 
-typedef struct _GoaWindowsLiveProviderClass GoaWindowsLiveProviderClass;
-
-struct _GoaWindowsLiveProviderClass
-{
-  GoaOAuth2ProviderClass parent_class;
-};
-
 /**
  * SECTION:goawindowsliveprovider
  * @title: GoaWindowsLiveProvider
